@@ -53,9 +53,9 @@ renderGauge <- function(div_id, theme = "default",
 
                         sep="")
 
-  to_eval <- paste("output$", div_id ," <- renderUI({fluidPage(tags$script(\"",
+  to_eval <- paste("output$", div_id ," <- renderUI({tags$script(\"",
                    js_statement,
-                   "\"))})",
+                   "\")})",
                    sep="")
 
   if(running_in_shiny == TRUE){
