@@ -101,9 +101,9 @@ renderRadarChart <- function(div_id,
 
                         sep="")
 
-  to_eval <- paste("output$", div_id ," <- renderUI({fluidPage(tags$script(\"",
+  to_eval <- paste("output$", div_id ," <- renderUI({tags$script(\"",
                    js_statement,
-                   "\"))})",
+                   "\")})",
                    sep="")
 
   if(running_in_shiny == TRUE){
